@@ -46,7 +46,7 @@ def fsim(x: torch.Tensor,
             of the angular Gaussian function used to construct filters in the frequency plane.
         k: No of standard deviations of the noise energy beyond the mean at which we set the noise
             threshold  point, below which phase congruency values get penalized.
-        
+
     Returns:
         Index of similarity betwen two images. Usually in [0, 1] interval.
         Can be bigger than 1 for predicted :math:`x` images with higher contrast than the original ones.
@@ -54,7 +54,7 @@ def fsim(x: torch.Tensor,
         L. Zhang, L. Zhang, X. Mou and D. Zhang, "FSIM: A Feature Similarity Index for Image Quality Assessment,"
         IEEE Transactions on Image Processing, vol. 20, no. 8, pp. 2378-2386, Aug. 2011, doi: 10.1109/TIP.2011.2109730.
         https://ieeexplore.ieee.org/document/5705575
-        
+
     """
 
     # Rescale to [0, 255] range, because all constant are calculated for this factor
@@ -86,26 +86,27 @@ def fsim(x: torch.Tensor,
         y_lum = y
 
     # Compute phase congruency maps
-    pc_x = _phase_congruency(x_lum,
-                             scales=scales,
-                             orientations=orientations,
-                             min_length=min_length,
-                             mult=mult,
-                             sigma_f=sigma_f,
-                             delta_theta=delta_theta,
-                             k=k)
-    pc_y = _phase_congruency(y_lum,
-                             scales=scales,
-                             orientations=orientations,
-                             min_length=min_length,
-                             mult=mult,
-                             sigma_f=sigma_f,
-                             delta_theta=delta_theta,
-                             k=k)
+    pc_x = _phase_congruency(
+        x_lum,
+        scales=scales,
+        orientations=orientations,
+        min_length=min_length,
+        mult=mult,
+        sigma_f=sigma_f,
+        delta_theta=delta_theta,
+        k=k)
+    pc_y = _phase_congruency(
+        y_lum,
+        scales=scales,
+        orientations=orientations,
+        min_length=min_length,
+        mult=mult,
+        sigma_f=sigma_f,
+        delta_theta=delta_theta,
+        k=k)
 
     # Gradient maps
-    scharr_filter = torch.tensor([[[-3., 0., 3.], [-10., 0., 10.],
-                                   [-3., 0., 3.]]]) / 16
+    scharr_filter = torch.tensor([[[-3., 0., 3.], [-10., 0., 10.], [-3., 0., 3.]]]) / 16
 
     kernels = torch.stack([scharr_filter, scharr_filter.transpose(-1, -2)])
     grad_map_x = gradient_map(x_lum, kernels)
@@ -121,7 +122,7 @@ def fsim(x: torch.Tensor,
     score = GM * PC * pc_max  # torch.sum(score)/torch.sum(pc_max)
 
     if chromatic:
-        assert num_channels == 3, "Chromatic component can be computed only for RGB images!"
+        assert num_channels == 3, 'Chromatic component can be computed only for RGB images!'
         S_I = similarity_map(x_i, y_i, T3)
         S_Q = similarity_map(x_q, y_q, T4)
         score = score * torch.abs(S_I * S_Q)**lmbda
@@ -143,7 +144,7 @@ def _construct_filters(x: torch.Tensor,
                        k: float = 2.0,
                        use_lowpass_filter=True):
     """Creates a stack of filters used for computation of phase congruensy maps
-    
+
     Args:
         x: Tensor. Shape :math:`(N, 1, H, W)`.
         scales: Number of wavelets
@@ -197,8 +198,7 @@ def _construct_filters(x: torch.Tensor,
     for s in range(scales):
         wavelength = min_length * mult**s
         omega_0 = 1.0 / wavelength
-        gabor_filter = torch.exp(
-            (-torch.log(radius / omega_0)**2) / (2 * math.log(sigma_f)**2))
+        gabor_filter = torch.exp((-torch.log(radius / omega_0)**2) / (2 * math.log(sigma_f)**2))
         if use_lowpass_filter:
             gabor_filter = gabor_filter * lp
         gabor_filter[0, 0] = 0
@@ -213,10 +213,8 @@ def _construct_filters(x: torch.Tensor,
         # the specified filter orientation.  To overcome the angular wrap-around
         # problem sine difference and cosine difference values are first computed
         # and then the atan2 function is used to determine angular distance.
-        ds = sintheta * math.cos(angl) - costheta * math.sin(
-            angl)  # Difference in sine.
-        dc = costheta * math.cos(angl) + sintheta * math.sin(
-            angl)  # Difference in cosine.
+        ds = sintheta * math.cos(angl) - costheta * math.sin(angl)  # Difference in sine.
+        dc = costheta * math.cos(angl) + sintheta * math.sin(angl)  # Difference in cosine.
         dtheta = torch.abs(torch.atan2(ds, dc))
         spread.append(torch.exp((-dtheta**2) / (2 * theta_sigma**2)))
 
@@ -224,8 +222,7 @@ def _construct_filters(x: torch.Tensor,
     log_gabor = torch.stack(log_gabor)
 
     # Multiply, add batch dimension and transfer to correct device.
-    filters = (spread.repeat_interleave(scales, dim=0) *
-               log_gabor.repeat(orientations, 1, 1)).unsqueeze(0).to(x)
+    filters = (spread.repeat_interleave(scales, dim=0) * log_gabor.repeat(orientations, 1, 1)).unsqueeze(0).to(x)
     return filters
 
 
@@ -261,14 +258,12 @@ def _phase_congruency(x: torch.Tensor,
     N, _, H, W = x.shape
 
     # Fourier transform
-    filters = _construct_filters(x, scales, orientations, min_length, mult,
-                                 sigma_f, delta_theta, k)
+    filters = _construct_filters(x, scales, orientations, min_length, mult, sigma_f, delta_theta, k)
 
     imagefft = torch.fft.fft2(x)
     filters_ifft = torch.fft.ifft2(filters)
     filters_ifft = filters_ifft.real * math.sqrt(H * W)
-    even_odd = torch.view_as_real(torch.fft.ifft2(imagefft * filters)).view(
-        N, orientations, scales, H, W, 2)
+    even_odd = torch.view_as_real(torch.fft.ifft2(imagefft * filters)).view(N, orientations, scales, H, W, 2)
 
     # Amplitude of even & odd filter response. An = sqrt(real^2 + imag^2)
     an = torch.sqrt(torch.sum(even_odd**2, dim=-1))
@@ -276,8 +271,7 @@ def _phase_congruency(x: torch.Tensor,
     # Take filter at scale 0 and sum spatially
     # Record mean squared filter value at smallest scale.
     # This is used for noise estimation.
-    em_n = (filters.view(1, orientations, scales, H,
-                         W)[:, :, :1, ...]**2).sum(dim=[-2, -1], keepdims=True)
+    em_n = (filters.view(1, orientations, scales, H, W)[:, :, :1, ...]**2).sum(dim=[-2, -1], keepdims=True)
 
     # Sum of even filter convolution results.
     sum_e = even_odd[..., 0].sum(dim=2, keepdims=True)
@@ -300,8 +294,7 @@ def _phase_congruency(x: torch.Tensor,
     even = even_odd[..., 0]
     odd = even_odd[..., 1]
 
-    energy = (even * mean_e + odd * mean_o -
-              torch.abs(even * mean_o - odd * mean_e)).sum(dim=2, keepdim=True)
+    energy = (even * mean_e + odd * mean_o - torch.abs(even * mean_o - odd * mean_e)).sum(dim=2, keepdim=True)
 
     # Compensate for noise
     # We estimate the noise power from the energy squared response at the
@@ -311,9 +304,7 @@ def _phase_congruency(x: torch.Tensor,
     # The estimate of noise power is obtained by dividing the mean squared
     # energy value by the mean squared filter value
 
-    abs_eo = torch.sqrt(torch.sum(even_odd[:, :, :1, ...]**2,
-                                  dim=-1)).reshape(N, orientations, 1, 1,
-                                                   H * W)
+    abs_eo = torch.sqrt(torch.sum(even_odd[:, :, :1, ...]**2, dim=-1)).reshape(N, orientations, 1, 1, H * W)
     median_e2n = torch.median(abs_eo**2, dim=-1, keepdim=True).values
 
     mean_e2n = -median_e2n / math.log(0.5)
@@ -329,9 +320,7 @@ def _phase_congruency(x: torch.Tensor,
 
     sum_ai_aj = torch.zeros(N, orientations, 1, H, W).to(x)
     for s in range(scales - 1):
-        sum_ai_aj = sum_ai_aj + (filters_ifft[:, :, s:s + 1] *
-                                 filters_ifft[:, :, s + 1:]).sum(dim=-3,
-                                                                 keepdim=True)
+        sum_ai_aj = sum_ai_aj + (filters_ifft[:, :, s:s + 1] * filters_ifft[:, :, s + 1:]).sum(dim=-3, keepdim=True)
 
     sum_an2 = torch.sum(sum_an2, dim=[-1, -2], keepdim=True)
     sum_ai_aj = torch.sum(sum_ai_aj, dim=[-1, -2], keepdim=True)
@@ -366,8 +355,7 @@ def _phase_congruency(x: torch.Tensor,
     return result_pc.unsqueeze(1)
 
 
-def _lowpassfilter(size: Tuple[int, int], cutoff: float,
-                   n: int) -> torch.Tensor:
+def _lowpassfilter(size: Tuple[int, int], cutoff: float, n: int) -> torch.Tensor:
     r"""
     Constructs a low-pass Butterworth filter.
     Args:
@@ -375,13 +363,13 @@ def _lowpassfilter(size: Tuple[int, int], cutoff: float,
         cutoff: Cutoff frequency of the filter in (0, 0.5()
         n: Filter order. Higher `n` means sharper transition.
             Note that `n` is doubled so that it is always an even integer.
-        
+
     Returns:
         f = 1 / (1 + w/cutoff) ^ 2n
-    
+
     """
-    assert 0 < cutoff <= 0.5, "Cutoff frequency must be between 0 and 0.5"
-    assert n > 1 and int(n) == n, "n must be an integer >= 1"
+    assert 0 < cutoff <= 0.5, 'Cutoff frequency must be between 0 and 0.5'
+    assert n > 1 and int(n) == n, 'n must be an integer >= 1'
 
     grid_x, grid_y = get_meshgrid(size)
 
@@ -435,10 +423,11 @@ class FSIM(nn.Module):
             k=k,
         )
 
-    def forward(self,
-                X: torch.Tensor,
-                Y: torch.Tensor,
-                ) -> torch.Tensor:
+    def forward(
+        self,
+        X: torch.Tensor,
+        Y: torch.Tensor,
+    ) -> torch.Tensor:
         r"""Computation of FSIM as a loss function.
         Args:
             x: An input tensor. Shape :math:`(N, C, H, W)`.
@@ -447,6 +436,6 @@ class FSIM(nn.Module):
             Value of FSIM loss to be minimized in [0, 1] range.
         """
 
-        assert X.shape == Y.shape, f"Input and reference images should have the same shape, but got {X.shape} and {Y.shape}"
+        assert X.shape == Y.shape, f'Input and reference images should have the same shape, but got {X.shape} and {Y.shape}'
         score = self.fsim(X, Y)
         return score
