@@ -1,6 +1,4 @@
 from collections import OrderedDict
-import fnmatch
-import re
 
 IMAGENET_DEFAULT_MEAN = (0.485, 0.456, 0.406)
 IMAGENET_DEFAULT_STD = (0.229, 0.224, 0.225)
@@ -51,6 +49,14 @@ DEFAULT_CONFIGS = OrderedDict({
         },
         'metric_mode': 'FR',
     },
+    'ssimc': {
+        'metric_opts': {
+            'type': 'SSIM',
+            'downsample': False,
+            'test_y_channel': False,
+        },
+        'metric_mode': 'FR',
+    },
     'psnr': {
         'metric_opts': {
             'type': 'PSNR',
@@ -58,6 +64,13 @@ DEFAULT_CONFIGS = OrderedDict({
         },
         'metric_mode': 'FR',
     },
+    'psnry': {
+        'metric_opts': {
+            'type': 'PSNR',
+            'test_y_channel': True,
+        },
+        'metric_mode': 'FR',
+    },
     'fsim': {
         'metric_opts': {
             'type': 'FSIM',
@@ -158,6 +171,13 @@ DEFAULT_CONFIGS = OrderedDict({
         'metric_mode': 'NR',
         'lower_better': True,
     },
+    'cnniqa': {
+        'metric_opts': {
+            'type': 'CNNIQA',
+            'pretrained': 'koniq10k'
+        },
+        'metric_mode': 'NR',
+    },
     'musiq': {
         'metric_opts': {
             'type': 'MUSIQ',
@@ -196,7 +216,16 @@ DEFAULT_CONFIGS = OrderedDict({
     'nima': {
         'metric_opts': {
             'type': 'NIMA',
-            'pretrained': 'ava'
+            'pretrained': 'ava',
+            'base_model_name': 'inception_resnet_v2',
+        },
+        'metric_mode': 'NR',
+    },
+    'nima-vgg16-ava': {
+        'metric_opts': {
+            'type': 'NIMA',
+            'pretrained': 'ava',
+            'base_model_name': 'vgg16',
         },
         'metric_mode': 'NR',
     },
@@ -232,5 +261,63 @@ DEFAULT_CONFIGS = OrderedDict({
         },
         'metric_mode': 'NR',
     },
+    'clipiqa': {
+        'metric_opts': {
+            'type': 'CLIPIQA',
+        },
+        'metric_mode': 'NR',
+    },
+    'clipiqa+': {
+        'metric_opts': {
+            'type': 'CLIPIQA',
+            'model_type': 'clipiqa+',
+        },
+        'metric_mode': 'NR',
+    },
+    'clipiqa+_vitL14_512': {
+        'metric_opts': {
+            'type': 'CLIPIQA',
+            'model_type': 'clipiqa+_vitL14_512',
+            'backbone': 'ViT-L/14',
+            'pos_embedding': True,
+        },
+        'metric_mode': 'NR',
+    },
+    'clipiqa+_rn50_512': {
+        'metric_opts': {
+            'type': 'CLIPIQA',
+            'model_type': 'clipiqa+_rn50_512',
+            'backbone': 'RN50',
+            'pos_embedding': True,
+        },
+        'metric_mode': 'NR',
+    },
+    'tres': {
+        'metric_opts': {
+            'type': 'TReS',
+            'train_dataset': 'koniq',
+        },
+        'metric_mode': 'NR',
+    },
+    'tres-koniq': {
+        'metric_opts': {
+            'type': 'TReS',
+            'train_dataset': 'koniq',
+        },
+        'metric_mode': 'NR',
+    },
+    'tres-flive': {
+        'metric_opts': {
+            'type': 'TReS',
+            'train_dataset': 'flive',
+        },
+        'metric_mode': 'NR',
+    },
+    'hyperiqa': {
+        'metric_opts': {
+            'type': 'HyperNet',
+        },
+        'metric_mode': 'NR',
+    },
 
 })
