@@ -20,6 +20,16 @@ def mse_loss(pred, target):
     return F.mse_loss(pred, target, reduction='none')
 
 
+@weighted_loss
+def cross_entropy(pred, target):
+    return F.cross_entropy(pred, target, reduction='none')
+
+
+@weighted_loss
+def nll_loss(pred, target):
+    return F.nll_loss(pred, target, reduction='none')
+
+
 @weighted_loss
 def charbonnier_loss(pred, target, eps=1e-12):
     return torch.sqrt((pred - target)**2 + eps)
@@ -81,6 +91,62 @@ class MSELoss(nn.Module):
         return self.loss_weight * mse_loss(pred, target, weight, reduction=self.reduction)
 
 
+@LOSS_REGISTRY.register()
+class CrossEntropyLoss(nn.Module):
+    """MSE (L2) loss.
+
+    Args:
+        loss_weight (float): Loss weight for MSE loss. Default: 1.0.
+        reduction (str): Specifies the reduction to apply to the output.
+            Supported choices are 'none' | 'mean' | 'sum'. Default: 'mean'.
+    """
+
+    def __init__(self, loss_weight=1.0, reduction='mean'):
+        super().__init__()
+        if reduction not in ['none', 'mean', 'sum']:
+            raise ValueError(f'Unsupported reduction mode: {reduction}. Supported ones are: {_reduction_modes}')
+
+        self.loss_weight = loss_weight
+        self.reduction = reduction
+
+    def forward(self, pred, target, weight=None, **kwargs):
+        """
+        Args:
+            pred (Tensor): of shape (N, C, H, W). Predicted tensor.
+            target (Tensor): of shape (N, C, H, W). Ground truth tensor.
+            weight (Tensor, optional): of shape (N, C, H, W). Element-wise weights. Default: None.
+        """
+        return self.loss_weight * cross_entropy(pred, target, weight, reduction=self.reduction)
+
+
+@LOSS_REGISTRY.register()
+class NLLLoss(nn.Module):
+    """MSE (L2) loss.
+
+    Args:
+        loss_weight (float): Loss weight for MSE loss. Default: 1.0.
+        reduction (str): Specifies the reduction to apply to the output.
+            Supported choices are 'none' | 'mean' | 'sum'. Default: 'mean'.
+    """
+
+    def __init__(self, loss_weight=1.0, reduction='mean'):
+        super().__init__()
+        if reduction not in ['none', 'mean', 'sum']:
+            raise ValueError(f'Unsupported reduction mode: {reduction}. Supported ones are: {_reduction_modes}')
+
+        self.loss_weight = loss_weight
+        self.reduction = reduction
+
+    def forward(self, pred, target, weight=None, **kwargs):
+        """
+        Args:
+            pred (Tensor): of shape (N, C, H, W). Predicted tensor.
+            target (Tensor): of shape (N, C, H, W). Ground truth tensor.
+            weight (Tensor, optional): of shape (N, C, H, W). Element-wise weights. Default: None.
+        """
+        return self.loss_weight * nll_loss(pred, target, weight, reduction=self.reduction)
+
+
 @LOSS_REGISTRY.register()
 class CharbonnierLoss(nn.Module):
     """Charbonnier loss (one variant of Robust L1Loss, a differentiable
@@ -142,5 +208,3 @@ class WeightedTVLoss(L1Loss):
         loss = x_diff + y_diff
 
         return loss
-
-
