@@ -1,6 +1,5 @@
 from .file_client import FileClient
-from .img_process_util import USMSharp, usm_sharp
-from .img_util import crop_border, imfrombytes, img2tensor, imwrite, tensor2img
+from .img_util import crop_border, imfrombytes, img2tensor, imwrite, tensor2img, imread2tensor
 from .logger import AvgTimer, MessageLogger, get_env_info, get_root_logger, init_tb_logger, init_wandb_logger
 from .misc import check_resume, get_time_str, make_exp_dirs, mkdir_and_rename, scandir, set_random_seed, sizeof_fmt
 
@@ -10,6 +9,7 @@ __all__ = [
     # file_client.py
     'FileClient',
     # img_util.py
+    'imread2tensor',
     'img2tensor',
     'tensor2img',
     'imfrombytes',
@@ -30,9 +30,6 @@ __all__ = [
     'scandir',
     'check_resume',
     'sizeof_fmt',
-    # img_process_util
-    'USMSharp',
-    'usm_sharp',
     # color util
     'rgb2ycbcr',
     'ycbcr2rgb',
